=====
AiiDA
=====
This is the official metapackage repository of AiiDA: an automated interactive infrastructure and database for computational science.
This package serves as a shortcut to install the ``aiida-core`` package, as well as the four original plugins ``aiida-quantumespresso``, ``aiida-ase``, ``aiida-codtools`` and ``aiida-nwchem``.
The official repositories for each of these packages can be found here:

* `aiida_core <https://github.com/aiidateam/aiida_core>`_
* `aiida-quantumespresso <https://github.com/aiidateam/aiida-quantumespresso>`_
* `aiida-nwchem <https://github.com/aiidateam/aiida-nwchem>`_
* `aiida-ase <https://github.com/aiidateam/aiida-ase>`_ 
* `aiida-codtools <https://github.com/aiidateam/aiida-codtools>`_

Documentation
=============
Documentation for the stable release of AiiDA can be found on `ReadTheDocs <http://aiida-core.readthedocs.io/en/stable/>`_.